#!/bin/bash
# Run QEMU virual machine

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

do_buildstep_prepend

: ${QEMU_BIN:="qemu-system-${arch_name}"}
: ${MACHINE:="virt"}
: ${CPU:=${cpu}}
: ${MEMORY_SIZE:=2048}
: ${QEMU_EXTRA_OPTS:=""}

: ${NFS_SERVER:=10.0.2.2}
: ${NFS_ROOT:=${ROOTFS_LOC}}
: ${NFS_PORT:=3048}
: ${NFS_MOUNT_PORT:=3049}

: ${KERNEL_IMAGE:=${NFS_ROOT}/boot/Image}
: ${DTB_IMAGE:=${NFS_ROOT}/boot/dtb}
: ${KERNEL_BOOT_OPTS:=${PROJECT_LOC}/output/nfsd}
: ${KERNEL_BOOT_OPTS:=${PROJECT_LOC}/output/nfsd}
: ${CLIENT_IP:=10.0.2.15}
: ${SERVER_IP:=""}
: ${GATEWAY_IP:=10.0.2.1}
: ${NETMASK:=255.255.255.0}

: ${serial_console:=115200:ttyAMA0}

if [ ! -z "${serial_console}" ]; then
	for i in $consoles
	do
		console_port=`echo ${i} | sed -e 's/^.*://' -e 's/:.*//'`
		console_baudrate=`echo ${i} | sed -e 's/:.*//' -e 's/^.*://'`
		console="${console_port},${console_baudrate}n8"
	done
fi

log_exec ${QEMU_BIN} \
	-machine ${MACHINE} \
	-cpu ${CPU} \
	-m ${MEMORY_SIZE} \
	-serial mon:vc \ # to redirect serial into qemu monitor
	-kernel ${KERNEL_IMAGE} \
	-append "ip=${CLIENT_IP}:${SERVER_IP}:${GATEWAY_IP}:${NETMASK} root=/dev/nfs rw console=${console} nfsroot=${NFS_SERVER}:${NFS_ROOT},port=${NFS_PORT},mountport=${NFS_MOUNT_PORT},v3,nolock,intr 0 0" \
	-netdev user,id=eth0,hostfwd=tcp::2022-:22,hostfwd=tcp::2345-:2345 \ # to redirect local port
	-device virtio-net-pci,netdev=eth0 \
	$QEMU_EXTRA_OPTS


do_buildstep_append
